# --------------------------------------
# Author: Andreas Alfons
#         Erasmus Universiteit Rotterdam
# --------------------------------------

#' @name robmed-package
#'
#' @docType package
#'
#' @title \packageTitle{robmed}
#'
#' @description \packageDescription{robmed}
#'
#' @details
#' The DESCRIPTION file:
#' \packageDESCRIPTION{robmed}
#' \packageIndices{robmed}
#'
#' @references
#' Alfons, A., Ates, N.Y. and Groenen, P.J.F. (2022a) A Robust Bootstrap Test
#' for Mediation Analysis.  \emph{Organizational Research Methods},
#' \bold{25}(3), 591--617.  doi:10.1177/1094428121999096.
#'
#' Alfons, A., Ates, N.Y. and Groenen, P.J.F. (2022b) Robust mediation analysis:
#' The \R package \pkg{robmed}.  \emph{Journal of Statistical Software},
#' \bold{103}(13), 1--45.  doi:10.18637/jss.v103.i13.
#'
#' @author
#' \packageAuthor{robmed}
#'
#' Maintainer: \packageMaintainer{robmed}
#'
#' @keywords package

"_PACKAGE"
